@@ -7,7 +7,7 @@ import os
 import re
 import pandas as pd
 
-import CustomModel
+import BaseModel
 import Jamo
 
 # 사전 & 사후 spacing
@@ -21,7 +21,7 @@ def tokenizer(text):
   return list(text.split(" "))
 
 # 사전 로드
-loaded_dct = Dictionary.load_from_text("data/dictionary.txt")
+loaded_dct = Dictionary.load_from_text("dictionary.txt")
 
 # 표기 오류가 있는 단어 indices, words return
 def check_error(word_list):
@@ -116,12 +116,9 @@ def seq2seq(text_list):
 
   return prediction_list
 
-default_word = pd.read_csv("data/clean_dataset.csv", names = ['num', 'words'])
+default_word = pd.read_csv("clean_dataset.csv", names = ['num', 'words'])
 default_word = list(default_word['words'])[1:]
 
-# default_word = pd.read_csv("data/spelled.txt")
-# default_word = list(default_word['text'])
-
 # 빠른 Edit Distance 도출을 위한 indexer
 indexer = LevenshteinIndex(default_word, verbose=True)
 
@@ -168,12 +165,12 @@ def compare(wrong_list, model_list, edit_list):
 
         else:
             size = len(edit_list[i])
-            
+
             if wrong_list[i] == model_list[i]: # model이 원래 text 그대로 output을 낸 경우
                 edit_only_word = "["
                 for j in range(size):
                     if j == (size-1):
-                        edit_only_word = edit_only_word + str(edit_list[i][j][0]) + "]"    
+                        edit_only_word = edit_only_word + str(edit_list[i][j][0]) + "]"
                     else:
                         edit_only_word = edit_only_word + str(edit_list[i][j][0]) + ", "
                 final_output.append(edit_only_word)
@@ -198,7 +195,7 @@ def compare(wrong_list, model_list, edit_list):
                             else:
                                 edit_only_word = edit_only_word + str(edit_list[i][j][0]) + ", "
                         final_output.append(edit_only_word)
-                        
+
     return final_output
 
 # 오류 교정된 단어 기존 리스트에 대체해주기 (문장부호 포함)
